@@ -188,25 +188,28 @@ bool DllVolChange(RAROptions *Cmd,wchar *NextName,size_t NameSize)
 
   if (Cmd->Callback!=NULL)
   {
-    wchar CurName[NM];
-    wcscpy(CurName,NextName);
+    wchar OrgNextName[NM];
+    wcscpy(OrgNextName,NextName);
     if (Cmd->Callback(UCM_CHANGEVOLUMEW,Cmd->UserData,(LPARAM)NextName,RAR_VOL_ASK)==-1)
       DllVolAborted=true;
     else
-      if (wcscmp(CurName,NextName)!=0)
+      if (wcscmp(OrgNextName,NextName)!=0)
         DllVolChanged=true;
       else
       {
-        char NextNameA[NM];
+        char NextNameA[NM],OrgNextNameA[NM];
         WideToChar(NextName,NextNameA,ASIZE(NextNameA));
+        strcpy(OrgNextNameA,NextNameA);
         if (Cmd->Callback(UCM_CHANGEVOLUME,Cmd->UserData,(LPARAM)NextNameA,RAR_VOL_ASK)==-1)
           DllVolAborted=true;
         else
-        {
-          CharToWide(NextNameA,NextName,NameSize);
-          if (wcscmp(CurName,NextName)!=0)
+          if (strcmp(OrgNextNameA,NextNameA)!=0)
+          {
+            // We can damage some Unicode characters by U->A->U conversion,
+            // so set Unicode name only if we see that ANSI name is changed.
+            CharToWide(NextNameA,NextName,NameSize);
             DllVolChanged=true;
-        }
+          }
       }
   }
   if (!DllVolChanged && Cmd->ChangeVolProc!=NULL)
